@@ -1,9 +1,9 @@
 # coding=utf-8
 #
 # This file is part of Hypothesis, which may be found at
-# https://github.com/HypothesisWorks/hypothesis-python
+# https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2018 David R. MacIver
+# Most of this work is copyright (C) 2013-2019 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -11,7 +11,7 @@
 #
 # This Source Code Form is subject to the terms of the Mozilla Public License,
 # v. 2.0. If a copy of the MPL was not distributed with this file, You can
-# obtain one at http://mozilla.org/MPL/2.0/.
+# obtain one at https://mozilla.org/MPL/2.0/.
 #
 # END HEADER
 
@@ -22,6 +22,7 @@ import datetime
 import decimal
 import fractions
 import functools
+import inspect
 import io
 import numbers
 import uuid
@@ -61,9 +62,24 @@ def try_issubclass(thing, superclass):
         return False
 
 
+def is_a_new_type(thing):
+    # At runtime, `typing.NewType` returns an identity function rather
+    # than an actual type, but we can check whether that thing matches.
+    return (
+        hasattr(thing, "__supertype__")
+        and hasattr(typing, "NewType")
+        and inspect.isfunction(thing)
+        and getattr(thing, "__module__", None) == "typing"
+    )
+
+
 def is_a_type(thing):
     """Return True if thing is a type or a generic type like thing."""
-    return isinstance(thing, type) or isinstance(thing, typing_root_type)
+    return (
+        isinstance(thing, type)
+        or isinstance(thing, typing_root_type)
+        or is_a_new_type(thing)
+    )
 
 
 def from_typing_type(thing):
